# Security Policy

## Supported Versions


| Version | Supported          |
| ------- | ------------------ |
| 0.1.x   | :white_check_mark: |
| < 0.1   | :x:                |

## Reporting a Vulnerability



Please report vulnerabilities by emailing [security@clew.ai](mailto:security@clew.ai). We will acknowledge your report within 48 hours.
